# Changelog

All notable changes to the **&lt;project name&gt;** SDK will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Please make sure to add your changes to the appropriate categories:

@weedge !TODO: see [Closed PR](https://github.com/ai-bot-pro/chat-bot/pulls?q=is%3Apr+is%3Aclosed) to add CHANGELOG